==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Extracted.java <==
package com.example.model;

/**
 * Model for Extracted
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "Extracted", description = "Model for Extracted")
@javax.xml.bind.annotation.XmlRootElement(name = "Extracted")
public class Extracted implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String address = null;
	private java.lang.String cardNumber = null;
	private java.lang.String city = null;
	private java.lang.String countryOfIssue = null;
	private java.lang.String dateOfBirth = null;
	private java.lang.String dateOfExpiry = null;
	private java.lang.String documentType = null;
	private java.lang.String firstName = null;
	private java.lang.String issuer = null;
	private java.lang.String lastName = null;
	private java.lang.String licenceClass = null;
	private java.lang.String licenceCondition = null;
	private java.lang.String licenceNumber = null;
	private java.lang.String middleName = null;
	private java.lang.String state = null;
	private java.lang.String street = null;
	private java.lang.String zipCode = null;
	
	/**
	 */
	public Extracted address(java.lang.String address) {
		setAddress(address);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("address")
	@javax.validation.constraints.NotNull
	public java.lang.String getAddress() {
		return this.address;
	}
	public void setAddress(java.lang.String address) {
		this.address = address;
	}
	
	/**
	 */
	public Extracted cardNumber(java.lang.String cardNumber) {
		setCardNumber(cardNumber);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("card_number")
	public java.lang.String getCardNumber() {
		return this.cardNumber;
	}
	public void setCardNumber(java.lang.String cardNumber) {
		this.cardNumber = cardNumber;
	}
	
	/**
	 */
	public Extracted city(java.lang.String city) {
		setCity(city);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("city")
	public java.lang.String getCity() {
		return this.city;
	}
	public void setCity(java.lang.String city) {
		this.city = city;
	}
	
	/**
	 */
	public Extracted countryOfIssue(java.lang.String countryOfIssue) {
		setCountryOfIssue(countryOfIssue);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("country_of_issue")
	public java.lang.String getCountryOfIssue() {
		return this.countryOfIssue;
	}
	public void setCountryOfIssue(java.lang.String countryOfIssue) {
		this.countryOfIssue = countryOfIssue;
	}
	
	/**
	 */
	public Extracted dateOfBirth(java.lang.String dateOfBirth) {
		setDateOfBirth(dateOfBirth);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("date_of_birth")
	public java.lang.String getDateOfBirth() {
		return this.dateOfBirth;
	}
	public void setDateOfBirth(java.lang.String dateOfBirth) {
		this.dateOfBirth = dateOfBirth;
	}
	
	/**
	 */
	public Extracted dateOfExpiry(java.lang.String dateOfExpiry) {
		setDateOfExpiry(dateOfExpiry);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("date_of_expiry")
	public java.lang.String getDateOfExpiry() {
		return this.dateOfExpiry;
	}
	public void setDateOfExpiry(java.lang.String dateOfExpiry) {
		this.dateOfExpiry = dateOfExpiry;
	}
	
	/**
	 */
	public Extracted documentType(java.lang.String documentType) {
		setDocumentType(documentType);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("document_type")
	public java.lang.String getDocumentType() {
		return this.documentType;
	}
	public void setDocumentType(java.lang.String documentType) {
		this.documentType = documentType;
	}
	
	/**
	 */
	public Extracted firstName(java.lang.String firstName) {
		setFirstName(firstName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("first_name")
	public java.lang.String getFirstName() {
		return this.firstName;
	}
	public void setFirstName(java.lang.String firstName) {
		this.firstName = firstName;
	}
	
	/**
	 */
	public Extracted issuer(java.lang.String issuer) {
		setIssuer(issuer);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("issuer")
	public java.lang.String getIssuer() {
		return this.issuer;
	}
	public void setIssuer(java.lang.String issuer) {
		this.issuer = issuer;
	}
	
	/**
	 */
	public Extracted lastName(java.lang.String lastName) {
		setLastName(lastName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("last_name")
	public java.lang.String getLastName() {
		return this.lastName;
	}
	public void setLastName(java.lang.String lastName) {
		this.lastName = lastName;
	}
	
	/**
	 */
	public Extracted licenceClass(java.lang.String licenceClass) {
		setLicenceClass(licenceClass);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("licence_class")
	public java.lang.String getLicenceClass() {
		return this.licenceClass;
	}
	public void setLicenceClass(java.lang.String licenceClass) {
		this.licenceClass = licenceClass;
	}
	
	/**
	 */
	public Extracted licenceCondition(java.lang.String licenceCondition) {
		setLicenceCondition(licenceCondition);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("licence_condition")
	public java.lang.String getLicenceCondition() {
		return this.licenceCondition;
	}
	public void setLicenceCondition(java.lang.String licenceCondition) {
		this.licenceCondition = licenceCondition;
	}
	
	/**
	 */
	public Extracted licenceNumber(java.lang.String licenceNumber) {
		setLicenceNumber(licenceNumber);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("licence_number")
	public java.lang.String getLicenceNumber() {
		return this.licenceNumber;
	}
	public void setLicenceNumber(java.lang.String licenceNumber) {
		this.licenceNumber = licenceNumber;
	}
	
	/**
	 */
	public Extracted middleName(java.lang.String middleName) {
		setMiddleName(middleName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("middle_name")
	public java.lang.String getMiddleName() {
		return this.middleName;
	}
	public void setMiddleName(java.lang.String middleName) {
		this.middleName = middleName;
	}
	
	/**
	 */
	public Extracted state(java.lang.String state) {
		setState(state);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("state")
	public java.lang.String getState() {
		return this.state;
	}
	public void setState(java.lang.String state) {
		this.state = state;
	}
	
	/**
	 */
	public Extracted street(java.lang.String street) {
		setStreet(street);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("street")
	public java.lang.String getStreet() {
		return this.street;
	}
	public void setStreet(java.lang.String street) {
		this.street = street;
	}
	
	/**
	 */
	public Extracted zipCode(java.lang.String zipCode) {
		setZipCode(zipCode);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("zip_code")
	public java.lang.String getZipCode() {
		return this.zipCode;
	}
	public void setZipCode(java.lang.String zipCode) {
		this.zipCode = zipCode;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Extracted extracted = (Extracted) o;
		return java.util.Objects.equals(this.address, extracted.address)
				&& java.util.Objects.equals(this.cardNumber, extracted.cardNumber)
				&& java.util.Objects.equals(this.city, extracted.city)
				&& java.util.Objects.equals(this.countryOfIssue, extracted.countryOfIssue)
				&& java.util.Objects.equals(this.dateOfBirth, extracted.dateOfBirth)
				&& java.util.Objects.equals(this.dateOfExpiry, extracted.dateOfExpiry)
				&& java.util.Objects.equals(this.documentType, extracted.documentType)
				&& java.util.Objects.equals(this.firstName, extracted.firstName)
				&& java.util.Objects.equals(this.issuer, extracted.issuer)
				&& java.util.Objects.equals(this.lastName, extracted.lastName)
				&& java.util.Objects.equals(this.licenceClass, extracted.licenceClass)
				&& java.util.Objects.equals(this.licenceCondition, extracted.licenceCondition)
				&& java.util.Objects.equals(this.licenceNumber, extracted.licenceNumber)
				&& java.util.Objects.equals(this.middleName, extracted.middleName)
				&& java.util.Objects.equals(this.state, extracted.state)
				&& java.util.Objects.equals(this.street, extracted.street)
				&& java.util.Objects.equals(this.zipCode, extracted.zipCode);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.address, this.cardNumber, this.city, this.countryOfIssue, this.dateOfBirth, this.dateOfExpiry, this.documentType, this.firstName, this.issuer, this.lastName, this.licenceClass, this.licenceCondition, this.licenceNumber, this.middleName, this.state, this.street, this.zipCode);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Extracted {\n");
		
		sb.append("    address: ").append(toIndentedString(this.address)).append("\n");
		sb.append("    cardNumber: ").append(toIndentedString(this.cardNumber)).append("\n");
		sb.append("    city: ").append(toIndentedString(this.city)).append("\n");
		sb.append("    countryOfIssue: ").append(toIndentedString(this.countryOfIssue)).append("\n");
		sb.append("    dateOfBirth: ").append(toIndentedString(this.dateOfBirth)).append("\n");
		sb.append("    dateOfExpiry: ").append(toIndentedString(this.dateOfExpiry)).append("\n");
		sb.append("    documentType: ").append(toIndentedString(this.documentType)).append("\n");
		sb.append("    firstName: ").append(toIndentedString(this.firstName)).append("\n");
		sb.append("    issuer: ").append(toIndentedString(this.issuer)).append("\n");
		sb.append("    lastName: ").append(toIndentedString(this.lastName)).append("\n");
		sb.append("    licenceClass: ").append(toIndentedString(this.licenceClass)).append("\n");
		sb.append("    licenceCondition: ").append(toIndentedString(this.licenceCondition)).append("\n");
		sb.append("    licenceNumber: ").append(toIndentedString(this.licenceNumber)).append("\n");
		sb.append("    middleName: ").append(toIndentedString(this.middleName)).append("\n");
		sb.append("    state: ").append(toIndentedString(this.state)).append("\n");
		sb.append("    street: ").append(toIndentedString(this.street)).append("\n");
		sb.append("    zipCode: ").append(toIndentedString(this.zipCode)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Extracted.java <==
package com.example.model;

/**
 * Model for Extracted
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "Extracted", description = "Model for Extracted")
@javax.xml.bind.annotation.XmlRootElement(name = "Extracted")
public class Extracted implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String address = null;
	private java.lang.String cardNumber = null;
	private java.lang.String city = null;
	private java.lang.String countryOfIssue = null;
	private java.lang.String dateOfBirth = null;
	private java.lang.String dateOfExpiry = null;
	private java.lang.String documentType = null;
	private java.lang.String firstName = null;
	private java.lang.String issuer = null;
	private java.lang.String lastName = null;
	private java.lang.String licenceClass = null;
	private java.lang.String licenceCondition = null;
	private java.lang.String licenceNumber = null;
	private java.lang.String middleName = null;
	private java.lang.String state = null;
	private java.lang.String street = null;
	private java.lang.String zipCode = null;
	
	/**
	 */
	public Extracted address(java.lang.String address) {
		setAddress(address);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "address")
	@com.fasterxml.jackson.annotation.JsonProperty("address")
	@javax.validation.constraints.NotNull
	public java.lang.String getAddress() {
		return this.address;
	}
	public void setAddress(java.lang.String address) {
		this.address = address;
	}
	
	/**
	 */
	public Extracted cardNumber(java.lang.String cardNumber) {
		setCardNumber(cardNumber);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "card_number")
	@com.fasterxml.jackson.annotation.JsonProperty("card_number")
	public java.lang.String getCardNumber() {
		return this.cardNumber;
	}
	public void setCardNumber(java.lang.String cardNumber) {
		this.cardNumber = cardNumber;
	}
	
	/**
	 */
	public Extracted city(java.lang.String city) {
		setCity(city);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "city")
	@com.fasterxml.jackson.annotation.JsonProperty("city")
	public java.lang.String getCity() {
		return this.city;
	}
	public void setCity(java.lang.String city) {
		this.city = city;
	}
	
	/**
	 */
	public Extracted countryOfIssue(java.lang.String countryOfIssue) {
		setCountryOfIssue(countryOfIssue);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "country_of_issue")
	@com.fasterxml.jackson.annotation.JsonProperty("country_of_issue")
	public java.lang.String getCountryOfIssue() {
		return this.countryOfIssue;
	}
	public void setCountryOfIssue(java.lang.String countryOfIssue) {
		this.countryOfIssue = countryOfIssue;
	}
	
	/**
	 */
	public Extracted dateOfBirth(java.lang.String dateOfBirth) {
		setDateOfBirth(dateOfBirth);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "date_of_birth")
	@com.fasterxml.jackson.annotation.JsonProperty("date_of_birth")
	public java.lang.String getDateOfBirth() {
		return this.dateOfBirth;
	}
	public void setDateOfBirth(java.lang.String dateOfBirth) {
		this.dateOfBirth = dateOfBirth;
	}
	
	/**
	 */
	public Extracted dateOfExpiry(java.lang.String dateOfExpiry) {
		setDateOfExpiry(dateOfExpiry);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "date_of_expiry")
	@com.fasterxml.jackson.annotation.JsonProperty("date_of_expiry")
	public java.lang.String getDateOfExpiry() {
		return this.dateOfExpiry;
	}
	public void setDateOfExpiry(java.lang.String dateOfExpiry) {
		this.dateOfExpiry = dateOfExpiry;
	}
	
	/**
	 */
	public Extracted documentType(java.lang.String documentType) {
		setDocumentType(documentType);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "document_type")
	@com.fasterxml.jackson.annotation.JsonProperty("document_type")
	public java.lang.String getDocumentType() {
		return this.documentType;
	}
	public void setDocumentType(java.lang.String documentType) {
		this.documentType = documentType;
	}
	
	/**
	 */
	public Extracted firstName(java.lang.String firstName) {
		setFirstName(firstName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "first_name")
	@com.fasterxml.jackson.annotation.JsonProperty("first_name")
	public java.lang.String getFirstName() {
		return this.firstName;
	}
	public void setFirstName(java.lang.String firstName) {
		this.firstName = firstName;
	}
	
	/**
	 */
	public Extracted issuer(java.lang.String issuer) {
		setIssuer(issuer);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "issuer")
	@com.fasterxml.jackson.annotation.JsonProperty("issuer")
	public java.lang.String getIssuer() {
		return this.issuer;
	}
	public void setIssuer(java.lang.String issuer) {
		this.issuer = issuer;
	}
	
	/**
	 */
	public Extracted lastName(java.lang.String lastName) {
		setLastName(lastName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "last_name")
	@com.fasterxml.jackson.annotation.JsonProperty("last_name")
	public java.lang.String getLastName() {
		return this.lastName;
	}
	public void setLastName(java.lang.String lastName) {
		this.lastName = lastName;
	}
	
	/**
	 */
	public Extracted licenceClass(java.lang.String licenceClass) {
		setLicenceClass(licenceClass);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "licence_class")
	@com.fasterxml.jackson.annotation.JsonProperty("licence_class")
	public java.lang.String getLicenceClass() {
		return this.licenceClass;
	}
	public void setLicenceClass(java.lang.String licenceClass) {
		this.licenceClass = licenceClass;
	}
	
	/**
	 */
	public Extracted licenceCondition(java.lang.String licenceCondition) {
		setLicenceCondition(licenceCondition);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "licence_condition")
	@com.fasterxml.jackson.annotation.JsonProperty("licence_condition")
	public java.lang.String getLicenceCondition() {
		return this.licenceCondition;
	}
	public void setLicenceCondition(java.lang.String licenceCondition) {
		this.licenceCondition = licenceCondition;
	}
	
	/**
	 */
	public Extracted licenceNumber(java.lang.String licenceNumber) {
		setLicenceNumber(licenceNumber);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "licence_number")
	@com.fasterxml.jackson.annotation.JsonProperty("licence_number")
	public java.lang.String getLicenceNumber() {
		return this.licenceNumber;
	}
	public void setLicenceNumber(java.lang.String licenceNumber) {
		this.licenceNumber = licenceNumber;
	}
	
	/**
	 */
	public Extracted middleName(java.lang.String middleName) {
		setMiddleName(middleName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "middle_name")
	@com.fasterxml.jackson.annotation.JsonProperty("middle_name")
	public java.lang.String getMiddleName() {
		return this.middleName;
	}
	public void setMiddleName(java.lang.String middleName) {
		this.middleName = middleName;
	}
	
	/**
	 */
	public Extracted state(java.lang.String state) {
		setState(state);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "state")
	@com.fasterxml.jackson.annotation.JsonProperty("state")
	public java.lang.String getState() {
		return this.state;
	}
	public void setState(java.lang.String state) {
		this.state = state;
	}
	
	/**
	 */
	public Extracted street(java.lang.String street) {
		setStreet(street);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "street")
	@com.fasterxml.jackson.annotation.JsonProperty("street")
	public java.lang.String getStreet() {
		return this.street;
	}
	public void setStreet(java.lang.String street) {
		this.street = street;
	}
	
	/**
	 */
	public Extracted zipCode(java.lang.String zipCode) {
		setZipCode(zipCode);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "zip_code")
	@com.fasterxml.jackson.annotation.JsonProperty("zip_code")
	public java.lang.String getZipCode() {
		return this.zipCode;
	}
	public void setZipCode(java.lang.String zipCode) {
		this.zipCode = zipCode;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Extracted extracted = (Extracted) o;
		return java.util.Objects.equals(this.address, extracted.address)
				&& java.util.Objects.equals(this.cardNumber, extracted.cardNumber)
				&& java.util.Objects.equals(this.city, extracted.city)
				&& java.util.Objects.equals(this.countryOfIssue, extracted.countryOfIssue)
				&& java.util.Objects.equals(this.dateOfBirth, extracted.dateOfBirth)
				&& java.util.Objects.equals(this.dateOfExpiry, extracted.dateOfExpiry)
				&& java.util.Objects.equals(this.documentType, extracted.documentType)
				&& java.util.Objects.equals(this.firstName, extracted.firstName)
				&& java.util.Objects.equals(this.issuer, extracted.issuer)
				&& java.util.Objects.equals(this.lastName, extracted.lastName)
				&& java.util.Objects.equals(this.licenceClass, extracted.licenceClass)
				&& java.util.Objects.equals(this.licenceCondition, extracted.licenceCondition)
				&& java.util.Objects.equals(this.licenceNumber, extracted.licenceNumber)
				&& java.util.Objects.equals(this.middleName, extracted.middleName)
				&& java.util.Objects.equals(this.state, extracted.state)
				&& java.util.Objects.equals(this.street, extracted.street)
				&& java.util.Objects.equals(this.zipCode, extracted.zipCode);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.address, this.cardNumber, this.city, this.countryOfIssue, this.dateOfBirth, this.dateOfExpiry, this.documentType, this.firstName, this.issuer, this.lastName, this.licenceClass, this.licenceCondition, this.licenceNumber, this.middleName, this.state, this.street, this.zipCode);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Extracted {\n");
		
		sb.append("    address: ").append(toIndentedString(this.address)).append("\n");
		sb.append("    cardNumber: ").append(toIndentedString(this.cardNumber)).append("\n");
		sb.append("    city: ").append(toIndentedString(this.city)).append("\n");
		sb.append("    countryOfIssue: ").append(toIndentedString(this.countryOfIssue)).append("\n");
		sb.append("    dateOfBirth: ").append(toIndentedString(this.dateOfBirth)).append("\n");
		sb.append("    dateOfExpiry: ").append(toIndentedString(this.dateOfExpiry)).append("\n");
		sb.append("    documentType: ").append(toIndentedString(this.documentType)).append("\n");
		sb.append("    firstName: ").append(toIndentedString(this.firstName)).append("\n");
		sb.append("    issuer: ").append(toIndentedString(this.issuer)).append("\n");
		sb.append("    lastName: ").append(toIndentedString(this.lastName)).append("\n");
		sb.append("    licenceClass: ").append(toIndentedString(this.licenceClass)).append("\n");
		sb.append("    licenceCondition: ").append(toIndentedString(this.licenceCondition)).append("\n");
		sb.append("    licenceNumber: ").append(toIndentedString(this.licenceNumber)).append("\n");
		sb.append("    middleName: ").append(toIndentedString(this.middleName)).append("\n");
		sb.append("    state: ").append(toIndentedString(this.state)).append("\n");
		sb.append("    street: ").append(toIndentedString(this.street)).append("\n");
		sb.append("    zipCode: ").append(toIndentedString(this.zipCode)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
